@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.23 2003/10/20 15:20:44 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.24 2003/11/26 20:29:52 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -211,6 +211,22 @@ get_str_resource(enum res_type rtype, char *strval)
 }
 
 
+/* Return the thousands separator character. For most locales, this is a 
+ * comma.
+ */
+
+char
+get_tsep_char()
+{
+    char *tsep_char;
+
+    setlocale(LC_NUMERIC, "");
+    tsep_char = nl_langinfo(THOUSEP);
+
+    return(tsep_char[0]);
+}
+
+
 void
 init_vars()    /* Setup default values for various variables. */
 {
@@ -349,6 +365,10 @@ read_resources()    /* Read all possible resources from the database. */
     if (get_bool_resource(R_ZEROES, &boolval)) {
         v->show_zeroes = boolval;
     }
+
+    if (get_bool_resource(R_TSEP, &boolval)) {
+        v->show_tsep = boolval;
+    }
 }
 
 
